Struct ToDeviceKeyVerificationKeyEventContent
#[non_exhaustive]pub struct ToDeviceKeyVerificationKeyEventContent {
pub transaction_id: OwnedTransactionId,
pub key: Base64,
}Expand description
The content of a to-device m.key.verification.key event.
Sends the ephemeral public key for a device to the partner device.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.transaction_id: OwnedTransactionIdAn opaque identifier for the verification process.
Must be the same as the one used for the m.key.verification.start message.
key: Base64The device’s ephemeral public key, encoded as unpadded base64.
Implementations
impl ToDeviceKeyVerificationKeyEventContent
impl ToDeviceKeyVerificationKeyEventContent
pub fn new(
transaction_id: OwnedTransactionId,
key: Base64,
) -> ToDeviceKeyVerificationKeyEventContent
pub fn new( transaction_id: OwnedTransactionId, key: Base64, ) -> ToDeviceKeyVerificationKeyEventContent
Creates a new ToDeviceKeyVerificationKeyEventContent with the given transaction ID and
key.